task teprof_s1 {
    String sample_id
    File fastq1
    File fastq2
    File STAR_INDEX_DIR

    String disk_size
    String docker
    String cluster

    command <<<
	
        set -o pipefail
        set -e
        pigz -p 8 -dc ${fastq1} > ${sample_id}_R1.fastq
        pigz -p 8 -dc ${fastq2} > ${sample_id}_R2.fastq
        STAR \
            --runThreadN 8 \
            --genomeDir ${STAR_INDEX_DIR} \
            --readFilesIn ${sample_id}_R1.fastq ${sample_id}_R2.fastq \
            --outSAMstrandField intronMotif \
            --outSAMtype BAM SortedByCoordinate \
            --outFileNamePrefix ./${sample_id}.

       samtools view -@ 16 -q 255 -h ${sample_id}.Aligned.sortedByCoord.out.bam > ${sample_id}.filtered.Aligned.sortedByCoord.out.bam
       stringtie -p 8 ${sample_id}.filtered.Aligned.sortedByCoord.out.bam -o ${sample_id}.Aligned.sortedByCoord.out.gtf -m 100 -c 1 --rf
       python /database/rnapipelinerefhg38/rnapipeline/rmskhg38_annotate_gtf_update_test_tpm.py ${sample_id}.Aligned.sortedByCoord.out.gtf /database/rnapipelinerefhg38/rnapipeline/arguments.txt

       python /database/rnapipelinerefhg38/rnapipeline/annotationtpmprocess.py ${sample_id}.Aligned.sortedByCoord.out.gtf_annotated_filtered_test
       
       mkdir ${sample_id}_annotated
       cp ${sample_id}.Aligned.sortedByCoord.out.gtf_annotated_* ${sample_id}_annotated
       tar -zcvf ${sample_id}_annotated.tgz ${sample_id}_annotated

       rm ${sample_id}.filtered.Aligned.sortedByCoord.out.bam
       rm ${sample_id}_R1.fastq
       rm ${sample_id}_R2.fastq
       

    >>>
	
    runtime {
        docker: docker
        cluster: cluster
        systemDisk: "cloud_ssd 40"
        dataDisk: "cloud_ssd " + disk_size + " /cromwell_root/"
    }

    output {
        File annotated = "${sample_id}_annotated.tgz"
        File annotated_use = "${sample_id}.Aligned.sortedByCoord.out.gtf_annotated_filtered_test_c" 
        File output_bam = "${sample_id}.Aligned.sortedByCoord.out.bam"
        File output_gtf = "${sample_id}.Aligned.sortedByCoord.out.gtf"
    }

}

